@@ -115,7 +115,7 @@ typedef unsigned int guintptr;
 
 #define GLIB_MAJOR_VERSION 2
 #define GLIB_MINOR_VERSION 58
-#define GLIB_MICRO_VERSION 0
+#define GLIB_MICRO_VERSION 2
 
 #define G_OS_UNIX
 
@@ -138,7 +138,7 @@ typedef unsigned int guintptr;
 #  undef G_HAVE_ISO_VARARGS
 #endif
 
-#undef G_HAVE_GROWING_STACK
+#define G_HAVE_GROWING_STACK 0
 #define G_HAVE_GNUC_VISIBILITY 1
 
 #ifndef _MSC_VER
